# SeismoPy
A Structural and Earthquake Engineering package.

## Installation
```pip install seismopy```

## How to use it?
Open terminal and type seismopy...

## License

© 2021 Mohsen Azimi

This repository is licensed under the MIT license. See LICENSE for details.